@@ -1,6 +1,8 @@
 from __future__ import division
 
 import math
+import multiprocessing
+from multiprocessing import Pool
 import os
 import os.path as osp
 from pathlib import Path
@@ -115,7 +117,9 @@ def split_video_from_stamps(
         output_paths=None,
         output_dirpath=None,
         filename_tmpl='video_{start_frame:05}_{end_frame:05}.mp4',
-        show_progress=True):
+        show_progress=True,
+        parallel_process=False,
+        n_jobs=8):
     if len(start_stamps) != len(end_stamps):
         raise RuntimeError(
             'Length not much len(start_stamps) != len(end_stamps)'
@@ -136,11 +140,25 @@ def split_video_from_stamps(
                                 / filename_tmpl.format(
                                     start_frame=start_frame,
                                     end_frame=end_frame))
-    for i, (s, e, video_out) in tqdm(enumerate(zip(
-            start_stamps, end_stamps, output_paths)),
-                                     total=len(output_paths),
-                                     disable=show_progress is False):
-        split_video(video_file_path, video_out, start_time=s, end_time=e)
+    if parallel_process is False:
+        for i, (s, e, video_out) in tqdm(enumerate(zip(
+                start_stamps, end_stamps, output_paths)),
+                                         total=len(output_paths),
+                                         disable=show_progress is False):
+            split_video(video_file_path, video_out, start_time=s, end_time=e)
+    else:
+        cpu_count = multiprocessing.cpu_count()
+        if n_jobs == -1 or n_jobs == 'full':
+            n_jobs = min(cpu_count, len(output_paths))
+        elif n_jobs == 'half':
+            n_jobs = min(cpu_count // 2, len(output_paths))
+        p = Pool(n_jobs)
+        for i, (s, e, video_out) in enumerate(zip(
+                start_stamps, end_stamps, output_paths)):
+            p.apply_async(split_video,
+                          args=(video_file_path, video_out, s, e))
+        p.close()
+        p.join()
     return output_paths
 
 
